@@ -10,7 +10,7 @@
 #' in that the graph includes both the targets and the imports,
 #' not just the imports.
 #' @export
-#' @seealso \code{\link{plan}}, \code{\link{make}}, \code{\link{plot_graph}}
+#' @seealso \code{\link{workplan}}, \code{\link{make}}, \code{\link{plot_graph}}
 #' @examples
 #' \dontrun{
 #' load_basic_example()
@@ -25,6 +25,7 @@
 #' @param targets same as for \code{\link{make}}
 #' @param envir same as for \code{\link{make}}
 #' @param verbose same as for \code{\link{make}}
+#' @param hook same as for \code{\link{make}}
 #' @param parallelism same as for \code{\link{make}}
 #' @param jobs same as for \code{\link{make}}
 #' @param packages same as for \code{\link{make}}
@@ -34,47 +35,53 @@
 #' @param args same as for \code{\link{make}}
 #' @param recipe_command same as for \code{\link{make}}
 #' @param cache same as for \code{\link{make}}
+#' @param timeout same as for \code{\link{make}}
+#' @param cpu same as for \code{\link{make}}
+#' @param elapsed same as for \code{\link{make}}
+#' @param retries same as for \code{\link{make}}
+#' @param clear_progress logical, whether to clear
+#' the cached progress of the targets readable by
+#' @param graph igraph object representing the workflow plan network
+#' \code{\link{progress}()}
 config <- function(
-  plan = drake::plan(), targets = drake::possible_targets(plan),
-  envir = parent.frame(), verbose = TRUE, cache = drake::get_cache(),
+  plan = workplan(),
+  targets = drake::possible_targets(plan),
+  envir = parent.frame(),
+  verbose = TRUE,
+  hook = function(code){
+    force(code)
+  },
+  cache = drake::get_cache(verbose = verbose),
   parallelism = drake::default_parallelism(),
-  jobs = 1, packages = (.packages()), prework = character(0),
-  prepend = character(0), command = drake::default_Makefile_command(),
-  args = drake::default_system2_args(
+  jobs = 1,
+  packages = rev(.packages()),
+  prework = character(0),
+  prepend = character(0),
+  command = drake::default_Makefile_command(),
+  args = drake::default_Makefile_args(
     jobs = jobs,
     verbose = verbose
   ),
-  recipe_command = drake::default_recipe_command()
+  recipe_command = drake::default_recipe_command(),
+  timeout = Inf,
+  cpu = timeout,
+  elapsed = timeout,
+  retries = 0,
+  clear_progress = FALSE,
+  graph = NULL
 ){
   force(envir)
-  config <- make(
-    imports_only = TRUE,
-    clear_progress = FALSE,
-    plan = plan, targets = targets,
-    envir = envir, verbose = verbose, cache = cache,
-    parallelism = parallelism, jobs = jobs,
-    packages = packages, prework = prework,
-    prepend = prepend, command = command, args = args,
-    recipe_command = recipe_command
-  )
-  config$graph <- build_graph(plan = plan, targets = targets,
-    envir = envir, verbose = verbose)
-  config
-}
-
-build_config <- function(
-  plan, targets, envir,
-  verbose, cache,
-  parallelism, jobs,
-  packages, prework, prepend, command,
-  args, clear_progress, recipe_command
-){
   seed <- get_valid_seed()
   plan <- sanitize_plan(plan)
   targets <- sanitize_targets(plan, targets)
-  parallelism <- match.arg(parallelism, choices = parallelism_choices())
-  prework <- add_packages_to_prework(packages = packages,
-    prework = prework)
+  parallelism <- match.arg(
+    parallelism,
+    choices = parallelism_choices(distributed_only = FALSE)
+  )
+  prework <- add_packages_to_prework(
+    packages = packages,
+    prework = prework
+  )
   if (is.null(cache)) {
     cache <- recover_cache()
   }
@@ -84,18 +91,20 @@ build_config <- function(
     clear_progress = clear_progress,
     overwrite_hash_algos = FALSE
   )
-  graph <- build_graph(plan = plan, targets = targets,
-    envir = envir, verbose = verbose
-  )
-  list(plan = plan, targets = targets, envir = envir, cache = cache,
-    parallelism = parallelism, jobs = jobs, verbose = verbose,
+  if (is.null(graph)){
+    graph <- build_graph(plan = plan, targets = targets,
+      envir = envir, verbose = verbose, jobs = jobs)
+  }
+  list(
+    plan = plan, targets = targets, envir = envir, cache = cache,
+    parallelism = parallelism, jobs = jobs, verbose = verbose, hook = hook,
     prepend = prepend, prework = prework, command = command,
     args = args, recipe_command = recipe_command, graph = graph,
     short_hash_algo = cache$get("short_hash_algo", namespace = "config"),
     long_hash_algo = cache$get("long_hash_algo", namespace = "config"),
     inventory = cache$list(), seed = seed,
     inventory_filemtime = cache$list(namespace = "filemtime"),
-    installed_packages = rownames(utils::installed.packages())
+    timeout = timeout, cpu = cpu, elapsed = elapsed, retries = retries
   )
 }
 
@@ -107,6 +116,15 @@ add_packages_to_prework <- function(packages, prework) {
     packages, ")", sep = "") %>% c(prework)
 }
 
+#' @title Internal function do_prework
+#' @export
+#' @description Run the \code{prework} of a \code{\link{make}()}.
+#' For internal use only.
+#' the only reason this function is exported
+#' is to set up PSOCK clusters efficiently.
+#' @param config internal configuration list
+#' @param verbose_packages logical, whether to print
+#' package startup messages
 do_prework <- function(config, verbose_packages) {
   wrapper <- ifelse(verbose_packages, invisible,
     base::suppressPackageStartupMessages)
@@ -133,13 +151,22 @@ inventory <- function(config) {
 #' load_basic_example()
 #' possible_targets(my_plan)
 #' }
-possible_targets <- function(plan = drake::plan()) {
+possible_targets <- function(plan = workplan()) {
   plan <- sanitize_plan(plan)
   c(as.character(plan$output), as.character(plan$target))
 }
 
 store_config <- function(config) {
   save_these <- setdiff(names(config), "envir")  # envir could get massive.
-  lapply(save_these, function(item) config$cache$set(key = item,
-    value = config[[item]], namespace = "config"))
+  lightly_parallelize(
+    save_these,
+    function(item){
+      config$cache$set(
+        key = item,
+        value = config[[item]],
+        namespace = "config"
+      )
+    },
+    jobs = config$jobs
+  )
 }
