@@ -4,15 +4,9 @@ dbug <- function() {
   envir <- dbug_envir(envir)
   dbug_files()
   plan <- dbug_plan()
-
-  build_config(plan = plan, targets = plan$target,
+  config(plan = plan, targets = plan$target,
     envir = envir, parallelism = scenario$parallelism,
-    jobs = scenario$jobs, prepend = character(0),
-    verbose = FALSE, packages = character(0),
-    prework = character(0), command = default_Makefile_command(),
-    args = character(0),
-    recipe_command = "Rscript -e",
-    cache = NULL, clear_progress = TRUE
+    jobs = scenario$jobs, verbose = FALSE
   )
 }
 
@@ -30,7 +24,7 @@ dbug_envir <- function(envir) {
 }
 
 dbug_plan <- function() {
-  plan(list = c(
+  workplan(list = c(
     `'intermediatefile.rds'` = "saveRDS(combined, \"intermediatefile.rds\")",
     yourinput = "f(1+1)",
     nextone = "myinput + g(7)",
