@@ -2,7 +2,7 @@
 #' @description Check which targets are out of date and need to be rebuilt.
 #' IMPORTANT: you must be in the root directory of your project.
 #' @export
-#' @seealso \code{\link{missed}}, \code{\link{plan}},
+#' @seealso \code{\link{missed}}, \code{\link{workplan}},
 #' \code{\link{make}}, \code{\link{plot_graph}}
 #' @examples
 #' \dontrun{
@@ -16,6 +16,7 @@
 #' @param envir same as for \code{\link{make}}. Overrides
 #' \code{config$envir}.
 #' @param verbose same as for \code{\link{make}}
+#' @param hook same as for \code{\link{make}}
 #' @param cache optional drake cache. See code{\link{new_cache}()}.
 #' The \code{cache} argument is ignored if a
 #' non-null \code{config} argument is supplied.
@@ -34,14 +35,17 @@
 #' in advance could save time if you plan multiple calls to
 #' \code{outdated()}.
 outdated <-  function(
-  plan = drake::plan(),
+  plan = workplan(),
   targets = drake::possible_targets(plan),
   envir = parent.frame(),
   verbose = TRUE,
-  cache = drake::get_cache(),
+  hook = function(code){
+    force(code)
+  },
+  cache = drake::get_cache(verbose = verbose),
   parallelism = drake::default_parallelism(),
   jobs = 1,
-  packages = (.packages()),
+  packages = rev(.packages()),
   prework = character(0),
   config = NULL
 ){
@@ -52,6 +56,7 @@ outdated <-  function(
       targets = targets,
       envir = envir,
       verbose = verbose,
+      hook = hook,
       cache = cache,
       parallelism = parallelism,
       jobs = jobs,
@@ -59,24 +64,27 @@ outdated <-  function(
       prework = prework
     )
   }
+  make_imports(config = config)
   config <- inventory(config)
   all_targets <- intersect(V(config$graph)$name, config$plan$target)
+  hash_list <- hash_list(targets = all_targets, config = config)
   rebuild <- Filter(
     x = all_targets,
     f = function(target){
-      hashes <- hashes(target, config)
+      hashes <- hash_list[[target]]
       !target_current(target = target, hashes = hashes, config = config)
     }
   )
   if (!length(rebuild)){
-    return(invisible(character(0)))
+    return(character(0))
   } else{
-    lapply(
+    lightly_parallelize(
       rebuild,
       function(vertex){
         subcomponent(config$graph, v = vertex, mode = "out")$name
-      }
-      ) %>%
+      },
+      jobs = jobs
+    ) %>%
     unlist() %>%
     unique() %>%
     sort()
@@ -84,30 +92,39 @@ outdated <-  function(
 }
 
 #' @title Function \code{missed}
-#' @description Report any import objects required by your workflow
+#' @description Report any import objects required by your workplan
 #' plan but missing from your workspace.
 #' IMPORTANT: you must be in the root directory of your project.
 #' @export
 #' @seealso \code{\link{outdated}}
+#'
 #' @param plan workflow plan data frame, same as for function
 #' \code{\link{make}()}.
+#'
 #' @param targets names of targets to build, same as for function
 #' \code{\link{make}()}.
+#'
 #' @param envir environment to import from, same as for function
 #' \code{\link{make}()}.
+#'
 #' @param verbose logical, whether to output messages to the console.
+#'
 #' @param jobs The \code{outdated()} function is called internally,
 #' and it needs to import objects and examine your
 #' input files to see what has been updated. This could take some time,
 #' and parallel computing may be needed
 #' to speed up the process. The \code{jobs} argument is number of parallel jobs
 #' to use for faster computation.
+#'
 #' @param parallelism Choice of parallel backend to speed up the computation.
 #' See \code{?parallelism_choices} for details. The Makefile option is not
 #' available here. Drake will try to pick the best option for your system by
 #' default.
+#'
 #' @param packages same as for \code{\link{make}}
+#'
 #' @param prework same as for \code{\link{make}}
+#'
 #' @param config option internal runtime parameter list of
 #' \code{\link{make}(...)},
 #' produced with \code{\link{config}()}.
@@ -116,6 +133,7 @@ outdated <-  function(
 #' Computing this
 #' in advance could save time if you plan multiple calls to
 #' \code{missed()}.
+#'
 #' @examples
 #' \dontrun{
 #' load_basic_example()
@@ -124,13 +142,13 @@ outdated <-  function(
 #' missed(my_plan)
 #' }
 missed <- function(
-  plan = drake::plan(),
+  plan = workplan(),
   targets = drake::possible_targets(plan),
   envir = parent.frame(),
   verbose = TRUE,
   jobs = 1,
   parallelism = drake::default_parallelism(),
-  packages = (.packages()),
+  packages = rev(.packages()),
   prework = character(0),
   config = NULL
 ){
@@ -156,7 +174,7 @@ missed <- function(
     }
   )
   if (!length(missing)){
-    return(invisible(character(0)))
+    return(character(0))
   }
   return(missing)
 }
