@@ -1,8 +1,8 @@
 #' @title Function \code{session}
 #' @description Load the \code{\link{sessionInfo}()}
 #' of the last call to \code{\link{make}()}.
-#' @seealso \code{\link{built}}, \code{\link{imported}},
-#' \code{\link{readd}}, \code{\link{plan}}, \code{\link{make}}
+#' @seealso \code{\link{diagnose}}, \code{\link{built}}, \code{\link{imported}},
+#' \code{\link{readd}}, \code{\link{workplan}}, \code{\link{make}}
 #' @export
 #' @return \code{\link{sessionInfo}()} of the last
 #' call to \code{\link{make}()}
@@ -15,6 +15,7 @@
 #' @param search If \code{TRUE}, search parent directories
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
+#' @param verbose whether to print console messages
 #' @examples
 #' \dontrun{
 #' load_basic_example()
@@ -22,7 +23,8 @@
 #' session()
 #' }
 session <- function(path = getwd(), search = TRUE,
-  cache = drake::get_cache(path = path, search = search)
+  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  verbose = TRUE
 ){
   if (is.null(cache)) {
     stop("No drake::make() session detected.")
@@ -35,9 +37,9 @@ session <- function(path = getwd(), search = TRUE,
 #' (1) are currently being built if \code{\link{make}()} is running, or
 #' (2) were in the process of being built if the previous call to
 #' \code{\link{make}()} quit unexpectedly.
-#' @seealso \code{\link{session}},
+#' @seealso \code{\link{diagnose}}, \code{\link{session}},
 #' \code{\link{built}}, \code{\link{imported}},
-#' \code{\link{readd}}, \code{\link{plan}}, \code{\link{make}}
+#' \code{\link{readd}}, \code{\link{workplan}}, \code{\link{make}}
 #' @export
 #' @return A character vector of target names
 #' @param cache optional drake cache. See code{\link{new_cache}()}.
@@ -49,20 +51,60 @@ session <- function(path = getwd(), search = TRUE,
 #' @param search If \code{TRUE}, search parent directories
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
+#' @param verbose whether to print console messages
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' make(my_plan) # Kill before targets finish.
+#' in_progress()
+#' }
+in_progress <- function(path = getwd(), search = TRUE,
+  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  verbose = TRUE
+){
+  prog <- progress(path = path, search = search, cache = cache)
+  which(prog == "in progress") %>%
+    names() %>%
+    as.character()
+}
+
+#' @title Function \code{failed}
+#' @description List the targets that failed in the last call
+#' to \code{\link{make}()}.
+#' Together, functions \code{failed} and
+#' \code{\link{diagnose}()} should eliminate the strict need
+#' for ordinary error messages printed to the console.
+#' @seealso \code{\link{diagnose}}, \code{\link{session}},
+#' \code{\link{built}}, \code{\link{imported}},
+#' \code{\link{readd}}, \code{\link{workplan}}, \code{\link{make}}
+#' @export
+#' @return A character vector of target names
+#' @param cache optional drake cache. See code{\link{new_cache}()}.
+#' If \code{cache} is supplied,
+#' the \code{path} and \code{search} arguments are ignored.
+#' @param path Root directory of the drake project,
+#' or if \code{search} is \code{TRUE}, either the
+#' project root or a subdirectory of the project.
+#' @param search If \code{TRUE}, search parent directories
+#' to find the nearest drake cache. Otherwise, look in the
+#' current working directory only.
+#' @param verbose whether to print console messages
 #' @examples
 #' \dontrun{
 #' load_basic_example()
 #' make(my_plan)
-#' in_progress() # nothing
-#' bad_plan = plan(x = function_doesnt_exist())
+#' failed() # nothing
+#' bad_plan <- workplan(x = function_doesnt_exist())
 #' make(bad_plan) # error
-#' in_progress() # "x"
+#' failed() # "x"
+#' diagnose(x)
 #' }
-in_progress <- function(path = getwd(), search = TRUE,
-  cache = drake::get_cache(path = path, search = search)
+failed <- function(path = getwd(), search = TRUE,
+  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  verbose = TRUE
 ){
   prog <- progress(path = path, search = search, cache = cache)
-  which(prog == "in progress") %>%
+  which(prog == "failed") %>%
     names() %>%
     as.character()
 }
@@ -73,31 +115,42 @@ in_progress <- function(path = getwd(), search = TRUE,
 #' Objects that drake imported, built, or attempted
 #' to build are listed as \code{"finished"} or \code{"in progress"}.
 #' Skipped objects are not listed.
-#' @seealso \code{\link{session}},
+#' @seealso \code{\link{diagnose}}, \code{\link{session}},
 #' \code{\link{built}}, \code{\link{imported}},
-#' \code{\link{readd}}, \code{\link{plan}}, \code{\link{make}}
+#' \code{\link{readd}}, \code{\link{workplan}}, \code{\link{make}}
 #' @export
+#'
 #' @return Statuses of targets
+#'
 #' @param ... objects to load from the cache, as names (unquoted)
 #' or character strings (quoted). Similar to \code{...} in
 #' \code{\link{remove}(...)}.
+#'
 #' @param list character vector naming objects to be loaded from the
 #' cache. Similar to the \code{list} argument of \code{\link{remove}()}.
+#'
 #' @param no_imported_objects logical, whether to only return information
 #' about imported files and targets with commands (i.e. whether to ignore
 #' imported objects that are not files).
+#'
 #' @param imported_files_only logical, deprecated. Same as
 #' \code{no_imported_objects}.  Use the \code{no_imported_objects} argument
 #' instead.
+#'
 #' @param cache optional drake cache. See code{\link{new_cache}()}.
 #' If \code{cache} is supplied,
 #' the \code{path} and \code{search} arguments are ignored.
+#'
 #' @param path Root directory of the drake project,
 #' or if \code{search} is \code{TRUE}, either the
 #' project root or a subdirectory of the project.
+#'
 #' @param search If \code{TRUE}, search parent directories
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
+#'
+#' @param verbose whether to print console messages
+#'
 #' @examples
 #' \dontrun{
 #' load_basic_example()
@@ -114,15 +167,17 @@ progress <- function(
   imported_files_only = logical(0),
   path = getwd(),
   search = TRUE,
-  cache = drake::get_cache(path = path, search = search)
+  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  verbose = TRUE
 ){
   # deprecate imported_files_only
   if (length(imported_files_only)){
     warning(
       "The imported_files_only argument to progress() is deprecated ",
       "and will be removed the next major release. ",
-      "Use the no_imported_objects argument instead."
-      )
+      "Use the no_imported_objects argument instead.",
+      call. = FALSE
+    )
     no_imported_objects <- imported_files_only
   }
   if (is.null(cache)){
