@@ -23,7 +23,7 @@ test_with_dir("storr_environment is a cache type", {
   expect_equal(short_hash(x), default_short_hash_algo())
   expect_equal(long_hash(x), default_long_hash_algo())
   expect_error(session(cache = x))
-  pln <- plan(y = 1)
+  pln <- workplan(y = 1)
   make(pln, cache = x, verbose = FALSE)
   expect_equal(cached(cache = x), "y")
   expect_false(file.exists(default_cache_path()))
@@ -81,24 +81,24 @@ test_with_dir("arbitrary storr in-memory cache", {
   expect_true(length(x) > 0)
   expect_true(nrow(y) > 0)
 
-  expect_equal(cached(), character(0))
+  expect_equal(cached(verbose = FALSE), character(0))
   targets <- my_plan$target
-  expect_true(all(targets %in% cached(cache = cache)))
+  expect_true(all(targets %in% cached(cache = cache, verbose = FALSE)))
   expect_false(file.exists(default_cache_path()))
 
-  expect_error(session())
-  expect_true(is.list(session(cache = cache)))
+  expect_error(session(verbose = FALSE))
+  expect_true(is.list(session(cache = cache, verbose = FALSE)))
   expect_false(file.exists(default_cache_path()))
 
-  expect_equal(length(imported()), 0)
-  expect_true(length(imported(cache = cache)) > 0)
+  expect_equal(length(imported(verbose = FALSE)), 0)
+  expect_true(length(imported(cache = cache, verbose = FALSE)) > 0)
   expect_false(file.exists(default_cache_path()))
 
-  expect_equal(length(built()), 0)
+  expect_equal(length(built(verbose = FALSE)), 0)
   expect_true(length(built(cache = cache)) > 0)
   expect_false(file.exists(default_cache_path()))
 
-  expect_equal(nrow(build_times()), 0)
+  expect_equal(nrow(build_times(verbose = FALSE)), 0)
   expect_true(nrow(build_times(cache = cache)) > 0)
   expect_false(file.exists(default_cache_path()))
 
@@ -113,38 +113,38 @@ test_with_dir("arbitrary storr in-memory cache", {
     cache = cache, verbose = FALSE, file = "graph.html")
   expect_false(file.exists(default_cache_path()))
 
-  m1 <- max_useful_jobs(my_plan, envir = envir, verbose = F)
+  m1 <- max_useful_jobs(my_plan, envir = envir, verbose = FALSE)
   unlink(default_cache_path(), recursive = TRUE)
-  m2 <- max_useful_jobs(my_plan, envir = envir, verbose = F, cache = cache)
+  m2 <- max_useful_jobs(my_plan, envir = envir, verbose = FALSE, cache = cache)
   expect_equal(m1, 8)
   expect_equal(m2, 4)
   expect_false(file.exists(default_cache_path()))
 
-  p1 <- progress()
+  p1 <- progress(verbose = FALSE)
   unlink(default_cache_path(), recursive = TRUE)
-  p2 <- progress(cache = cache)
+  p2 <- progress(cache = cache, verbose = FALSE)
   expect_true(length(p2) > length(p1))
   expect_false(file.exists(default_cache_path()))
 
-  expect_error(read_config())
-  expect_true(is.list(read_config(cache = cache)))
+  expect_error(read_config(verbose = FALSE))
+  expect_true(is.list(read_config(cache = cache, verbose = FALSE)))
   expect_false(file.exists(default_cache_path()))
 
-  expect_error(read_graph())
-  expect_equal(class(read_graph(cache = cache)), "igraph")
+  expect_error(read_graph(verbose = FALSE))
+  expect_equal(class(read_graph(cache = cache, verbose = FALSE)), "igraph")
   expect_false(file.exists(default_cache_path()))
 
-  expect_error(read_plan())
-  expect_true(is.data.frame(read_plan(cache = cache)))
+  expect_error(read_plan(verbose = FALSE))
+  expect_true(is.data.frame(read_plan(cache = cache, verbose = FALSE)))
   expect_false(file.exists(default_cache_path()))
 
-  expect_error(readd(small))
-  expect_true(is.data.frame(readd(small, cache = cache)))
+  expect_error(readd(small, verbose = FALSE))
+  expect_true(is.data.frame(readd(small, cache = cache, verbose = FALSE)))
   expect_false(file.exists(default_cache_path()))
 
-  expect_error(loadd(large))
+  expect_error(loadd(large, verbose = FALSE))
   expect_error(nrow(large))
-  expect_silent(loadd(large, cache = cache))
+  expect_silent(loadd(large, cache = cache, verbose = FALSE))
   expect_true(nrow(large) > 0)
   rm(large)
   expect_false(file.exists(default_cache_path()))
