@@ -17,15 +17,36 @@ test_with_dir("basic example works", {
 
   # Different graph configurations should be checked manually.
   tmp <- dataframes_graph(my_plan, envir = e, config = config)
+  tmpcopy <- dataframes_graph(my_plan, envir = e, config = config,
+    from_scratch = TRUE)
+  tmp0 <- dataframes_graph(my_plan, envir = e, config = config,
+    subset = c("small", "regression2_large"))
+  tmp1 <- dataframes_graph(my_plan, envir = e, config = config,
+    from = "small")
   tmp2 <- dataframes_graph(my_plan, envir = e, config = config,
-    targets_only = TRUE)
+    from = "small", targets_only = TRUE, parallelism = "Makefile")
   tmp3 <- dataframes_graph(my_plan, envir = e, config = config,
-    split_columns = TRUE)
+    targets_only = TRUE)
   tmp4 <- dataframes_graph(my_plan, envir = e, config = config,
+    split_columns = TRUE)
+  tmp5 <- dataframes_graph(my_plan, envir = e, config = config,
     targets_only = TRUE, split_columns = TRUE)
+  expect_warning(
+    tmp6 <- dataframes_graph(my_plan, envir = e, config = config,
+      from = c("small", "not_found"))
+  )
+  expect_error(
+    tmp7 <- dataframes_graph(my_plan, envir = e, config = config,
+      from = "not_found")
+  )
+  expect_equal(nrow(tmp0$nodes), 2)
+  expect_true(identical(tmp$nodes, tmpcopy$nodes))
+  expect_false(identical(tmp$nodes, tmp0$nodes))
+  expect_false(identical(tmp$nodes, tmp1$nodes))
   expect_false(identical(tmp$nodes, tmp2$nodes))
   expect_false(identical(tmp$nodes, tmp3$nodes))
   expect_false(identical(tmp$nodes, tmp4$nodes))
+  expect_false(identical(tmp$nodes, tmp5$nodes))
 
   expect_false(file.exists("Makefile"))
   expect_true(is.data.frame(tmp$nodes))
@@ -54,6 +75,13 @@ test_with_dir("basic example works", {
   dats <- c("small", "large")
   config$targets <- dats
   con <- testrun(config)
+
+  expect_equal(parallelism == "Makefile", file.exists("Makefile"))
+  tmp1 <- dataframes_graph(my_plan, envir = e, config = config)
+  tmp2 <- dataframes_graph(my_plan, envir = e, config = config,
+    from_scratch = TRUE)
+  expect_false(identical(tmp1$nodes, tmp2$nodes))
+
   expect_equal(sort(justbuilt(con)), sort(dats))
   remove_these <- intersect(dats, ls(config$envir))
   rm(list = remove_these, envir = config$envir)
@@ -70,7 +98,7 @@ test_with_dir("basic example works", {
 
   config <- config(my_plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = FALSE)
-  expect_equal(parallelism == "Makefile", file.exists("Makefile"))
+
   expect_equal(outdated(my_plan, envir = e, jobs = jobs,
     parallelism = parallelism,
     verbose = FALSE), character(0))
