@@ -1,5 +1,23 @@
 drake_context("console")
 
+test_with_dir("console_up_to_date", {
+  pl <- workplan(a = 1)
+  con <- make(pl, verbose = FALSE)
+  expect_silent(console_up_to_date(con))
+  con$verbose <- TRUE
+  expect_silent(console_up_to_date(con))
+  con <- make(pl, verbose = FALSE)
+  con$verbose <- TRUE
+  expect_output(console_up_to_date(con))
+})
+
+test_with_dir("console_parLapply", {
+  config <- list(verbose = TRUE)
+  expect_output(console_parLapply(config = config)) # nolint
+  config <- list(verbose = FALSE)
+  expect_silent(console_parLapply(config = config)) # nolint
+})
+
 test_with_dir("multiline message cap", {
   n <- 100
   x1 <- "aldksjf"
