@@ -22,7 +22,7 @@ test_with_dir(
   expect_false(is_vectorized(f))
   expect_false(is_vectorized("char"))
   expect_equal(sort(deps(f)), sort(c("g", "saveRDS")))
-  my_plan <- plan(
+  my_plan <- workplan(
     x = 1 + some_object,
     my_target = x + readRDS("tracked_input_file.rds"),
     return_value = f(x, y, g(z + w)))
@@ -44,14 +44,15 @@ test_with_dir(
 
 test_with_dir("tracked() works", {
   config <- dbug()
-  x <- sort(tracked(plan = config$plan, envir = config$envir))
+  x <- sort(
+    tracked(plan = config$plan, envir = config$envir, verbose = FALSE))
   y <- sort(c("'intermediatefile.rds'",
     "yourinput", "nextone",
     "combined", "myinput", "final", "j", "i", "h", "g", "f",
     "c", "b", "a", "saveRDS", "'input.rds'", "readRDS"))
   expect_equal(x, y)
   x <- sort(tracked(plan = config$plan, targets = "myinput",
-    envir = config$envir))
+    envir = config$envir, verbose = FALSE))
   y <- sort(c("myinput", "'input.rds'", "readRDS"))
   expect_equal(x, y)
 })
