@@ -1,6 +1,7 @@
 drake_context("edge cases")
 
 test_with_dir("deprecation", {
+  expect_warning(default_system2_args(jobs = 1, verbose = FALSE))
   plan <- data.frame(code = 1:2, output = c("x", "y"))
   expect_warning(make(plan, verbose = FALSE))
   expect_warning(make(plan, verbose = FALSE))
@@ -8,12 +9,22 @@ test_with_dir("deprecation", {
   expect_true(is.numeric(readd(x, search = FALSE)))
   expect_warning(prune(plan[1, ]))
   expect_equal(cached(), "x")
-  expect_warning(make(plan(x = 1), return_config = TRUE,
+  expect_warning(make(workplan(x = 1), return_config = TRUE,
     verbose = FALSE))
-  x <- this_cache()
+  expect_warning(make(workplan(x = 1), clear_progress = TRUE,
+    verbose = FALSE))
+  expect_silent(make(workplan(x = 1), imports_only = TRUE,
+    verbose = FALSE))
+  pl1 <- expect_warning(drake::plan(x = 1, y = x))
+  pl2 <- workplan(x = 1, y = x)
+  expect_warning(drake::plan())
+  expect_warning(drake::plan(x = y, file_targets = TRUE))
+  expect_warning(drake::workflow())
+  expect_warning(drake::workflow(x = y, file_targets = TRUE))
 
   # We need to be able to set the drake version
   # to check back compatibility.
+  x <- this_cache()
   x$del(key = "initial_drake_version", namespace = "session")
   expect_false("initial_drake_version" %in% x$list(namespace = "session"))
   set_initial_drake_version(cache = x)
@@ -21,7 +32,7 @@ test_with_dir("deprecation", {
 })
 
 test_with_dir("graph does not fail if input file is binary", {
-  x <- plan(y = readRDS("input.rds"))
+  x <- workplan(y = readRDS("input.rds"))
   saveRDS(as.list(mtcars), "input.rds")
   expect_silent(out <- plot_graph(x, verbose = FALSE))
   unlink("input.rds", force = TRUE)
@@ -33,14 +44,14 @@ test_with_dir("null graph", {
 })
 
 test_with_dir("illegal hashes", {
-  x <- plan(a = 1)
+  x <- workplan(a = 1)
   expect_error(make(x, short_hash_algo = "no_such_algo_aslkdjfoiewlk"))
   expect_error(make(x, long_hash_algo = "no_such_algo_aslkdjfoiewlk"))
 })
 
-test_with_dir("different graphical arrangements for Makefile parallelism", {
+test_with_dir("different graphical arrangements for distributed parallelism", {
   e <- new.env()
-  x <- plan(a = 1, b = f(2))
+  x <- workplan(a = 1, b = f(2))
   e$f <- function(x) x
   con <- config(x, envir = e, verbose = FALSE)
   expect_equal(1, max_useful_jobs(x, envir = e, config = con,
@@ -50,6 +61,11 @@ test_with_dir("different graphical arrangements for Makefile parallelism", {
   con$parallelism <- "Makefile"
   expect_equal(2, max_useful_jobs(x, envir = e, config = con,
     parallelism = "Makefile", jobs = 1))
+  expect_equal(2, max_useful_jobs(x, envir = e, config = con,
+    parallelism = "future_lapply", jobs = 1))
+  y <- workplan(a = 1, b = 2)
+  tmp <- dataframes_graph(y, parallelism = "Makefile", verbose = FALSE)
+  expect_true(is.list(tmp))
 })
 
 test_with_dir("Vectorized nested functions work", {
@@ -60,7 +76,7 @@ test_with_dir("Vectorized nested functions work", {
   e$y <- 7
   config <- dbug()
   config$envir <- e
-  config$plan <- plan(a = f(1:10))
+  config$plan <- workplan(a = f(1:10))
   config$targets <- "a"
   expect_equal(deps(e$f), "g")
   expect_equal(deps(e$g), "y")
@@ -104,8 +120,8 @@ test_with_dir("stringsAsFactors can be TRUE", {
   expect_equal(readd(a), "helloworld")
 })
 
-test_with_dir("circular non-DAG workflows quit in error", {
-  p <- plan(a = b, b = c, c = a)
+test_with_dir("circular non-DAG workplans quit in error", {
+  p <- workplan(a = b, b = c, c = a)
   expect_error(tmp <- capture.output(check(p)))
   expect_error(make(p, verbose = FALSE))
 })
@@ -135,7 +151,7 @@ test_with_dir("target conflicts with previous import", {
 })
 
 test_with_dir("can use semicolons and multi-line commands", {
-  plan <- plan(list = c(x = "a<-1; a", y = "b<-2\nb"))
+  plan <- workplan(list = c(x = "a<-1; a", y = "b<-2\nb"))
   make(plan, verbose = FALSE)
   expect_false(any(c("a", "b") %in% ls()))
   expect_true(all(cached(x, y, search = FALSE)))
@@ -146,7 +162,7 @@ test_with_dir("true targets can be functions", {
   generator <- function() return(function(x) {
     x + 1
   })
-  plan <- plan(myfunction = generator(), output = myfunction(1))
+  plan <- workplan(myfunction = generator(), output = myfunction(1))
   config <- make(plan, verbose = FALSE)
   expect_equal(readd(output), 2)
   expect_true(is.list(config$cache$get("myfunction")))
@@ -155,7 +171,7 @@ test_with_dir("true targets can be functions", {
 })
 
 test_with_dir("error when file target names do not match actual filenames", {
-  x <- plan(y = 1, file_targets = TRUE)
+  x <- workplan(y = 1, file_targets = TRUE)
   expect_warning(expect_error(make(x, verbose = FALSE)))
 })
 
